==> freecad_0.16.6712+dfsg1.orig.tar.xz: FreeCAD-0.16.6712/src/Mod/Plot/resources/translations/Plot_sk.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="sk" sourcelanguage="en">
  <context>
    <name>Plot</name>
    <message>
      <location filename="InitGui.py" line="44"/>
      <source>Plot edition tools</source>
      <translation>Nástroje úpravy grafu</translation>
    </message>
    <message>
      <location filename="InitGui.py" line="47"/>
      <source>Plot</source>
      <translation>Graf</translation>
    </message>
  </context>
  <context>
    <name>Plot_Axes</name>
    <message>
      <location filename="PlotGui.py" line="62"/>
      <source>Configure axes</source>
      <translation>Nastaviť osi</translation>
    </message>
    <message>
      <location filename="PlotGui.py" line="65"/>
      <source>Configure the axes parameters</source>
      <translation>Nastaviť parametre osí</translation>
    </message>
  </context>
  <context>
    <name>Plot_Grid</name>
    <message>
      <location filename="PlotGui.py" line="110"/>
      <source>Show/Hide grid</source>
      <translation>Zobraziť/skryť mriežku</translation>
    </message>
    <message>
      <location filename="PlotGui.py" line="113"/>
      <source>Show/Hide grid on selected plot</source>
      <translation>Zobraziť/skryť mriežku vybraného grafu</translation>
    </message>
  </context>
  <context>
    <name>Plot_Labels</name>
    <message>
      <location filename="PlotGui.py" line="154"/>
      <source>Set labels</source>
      <translation>Nastaviť popisy</translation>
    </message>
    <message>
      <location filename="PlotGui.py" line="157"/>
      <source>Set title and axes labels</source>
      <translation>Nastaviť nadpis a popisy osí</translation>
    </message>
  </context>
  <context>
    <name>Plot_Legend</name>
    <message>
      <location filename="PlotGui.py" line="137"/>
      <source>Show/Hide legend</source>
      <translation>Zobraziť/skryť legendu</translation>
    </message>
    <message>
      <location filename="PlotGui.py" line="140"/>
      <source>Show/Hide legend on selected plot</source>
      <translation>Zobraziť/skryť legendu vo vybranom grafe</translation>
    </message>
  </context>
  <context>
    <name>Plot_Positions</name>
    <message>
      <location filename="PlotGui.py" line="171"/>
      <source>Set positions and sizes</source>
      <translation>Nastavenie pozície a veľkosti</translation>
    </message>
    <message>
      <location filename="PlotGui.py" line="174"/>
      <source>Set labels and legend positions and sizes</source>
      <translation>Nastavenie pozície a veľkosti popisov a legendy</translation>
    </message>
  </context>
  <context>
    <name>Plot_SaveFig</name>
    <message>
      <location filename="PlotGui.py" line="45"/>
      <source>Save plot</source>
      <translation>Uložiť graf</translation>
    </message>
    <message>
      <location filename="PlotGui.py" line="48"/>
      <source>Save the plot as an image file</source>
      <translation>Uložiť graf ako obrázok</translation>
    </message>
  </context>
  <context>
    <name>Plot_Series</name>
    <message>
      <location filename="PlotGui.py" line="81"/>
      <source>Configure series</source>
      <translation>Nastavenie série</translation>
    </message>
    <message>
      <location filename="PlotGui.py" line="84"/>
      <source>Configure series drawing style and label</source>
      <translation>Nastavenie štýlu a popisu pre sériu</translation>
    </message>
  </context>
  <context>
    <name>plot_axes</name>
    <message>
      <location filename="TaskPanel.py" line="175"/>
      <source>Configure axes</source>
      <translation>Nastaviť osi</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="180"/>
      <source>Active axes</source>
      <translation>Aktívne osi</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="220"/>
      <source>Apply to all axes</source>
      <translation>Aplikovať na všetky osi</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="225"/>
      <source>Dimensions</source>
      <translation>Rozmery</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="230"/>
      <source>X axis position</source>
      <translation>Poloha osi X</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="235"/>
      <source>Y axis position</source>
      <translation>Poloha osi Y</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="205"/>
      <source>Scales</source>
      <translation>Mierka</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="210"/>
      <source>X auto</source>
      <translation>X automaticky</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="215"/>
      <source>Y auto</source>
      <translation>Y automaticky</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="240"/>
      <source>Index of the active axes</source>
      <translation>Popis aktívnych osí</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="245"/>
      <source>Add new axes to the plot</source>
      <translation>Pridať nové osi do grafu</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="251"/>
      <source>Remove selected axes</source>
      <translation>Odobrať vybrané osi</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="257"/>
      <source>Check it to apply transformations to all axes</source>
      <translation>Zaškrtnite pre povolenie transformácií vo všetkých osách</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="263"/>
      <source>Left bound of axes</source>
      <translation>Ľavá medza osí</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="269"/>
      <source>Right bound of axes</source>
      <translation>Pravá medza osí</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="275"/>
      <source>Bottom bound of axes</source>
      <translation>Spodná medza osí</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="281"/>
      <source>Top bound of axes</source>
      <translation>Horná medza osí</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="287"/>
      <source>Outward offset of X axis</source>
      <translation>Vonkajšie odsadenie osi X</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="293"/>
      <source>Outward offset of Y axis</source>
      <translation>Vonkajšie odsadenie osi Y</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="299"/>
      <source>X axis scale autoselection</source>
      <translation>Automatická mierka osi X</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="305"/>
      <source>Y axis scale autoselection</source>
      <translation>Automatická mierka osi Y</translation>
    </message>
  </context>
  <context>
    <name>plot_console</name>
    <message>
      <location filename="Plot.py" line="43"/>
      <source>matplotlib not found, so Plot module can not be loaded</source>
      <translation>modul Graf nemohol byť načítaný, pretože knižnica matplotlib nebola nájdená</translation>
    </message>
    <message>
      <location filename="InitGui.py" line="54"/>
      <source>matplotlib not found, Plot module will be disabled</source>
      <translation>knižnica matplotlib nebola nájdená, modul Graf bude deaktivovaný</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="42"/>
      <source>Plot document must be selected in order to save it</source>
      <translation>Dokument grafu musí byť vybraný, aby mohol byť uložený</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="365"/>
      <source>Axes 0 can not be deleted</source>
      <translation>Osi 0 nemôžu byť zmazané</translation>
    </message>
    <message>
      <location filename="PlotGui.py" line="97"/>
      <source>The grid must be activated on top of a plot document</source>
      <translation>Mriežka grafu musí byť aktivovaná hore v dokumente grafu</translation>
    </message>
    <message>
      <location filename="PlotGui.py" line="126"/>
      <source>The legend must be activated on top of a plot document</source>
      <translation>Legenda musí byť aktivovaná hore v dokumente grafu</translation>
    </message>
  </context>
  <context>
    <name>plot_labels</name>
    <message>
      <location filename="TaskPanel.py" line="133"/>
      <source>Set labels</source>
      <translation>Nastaviť popisy</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="138"/>
      <source>Active axes</source>
      <translation>Aktívne osi</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="143"/>
      <source>Title</source>
      <translation>Nadpis</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="148"/>
      <source>X label</source>
      <translation>Popis osi X</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="153"/>
      <source>Y label</source>
      <translation>Popis osi Y</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="158"/>
      <source>Index of the active axes</source>
      <translation>Popis aktívnych osí</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="163"/>
      <source>Title (associated to active axes)</source>
      <translation>Nadpis (pripojený k aktívnym osám)</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="169"/>
      <source>Title font size</source>
      <translation>Veľkosť písma nadpisu</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="175"/>
      <source>X axis title</source>
      <translation>Nadpis na ose X</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="181"/>
      <source>X axis title font size</source>
      <translation>Velľkosť písma nadpisu na ose X</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="187"/>
      <source>Y axis title</source>
      <translation>Nadpis na ose Y</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="193"/>
      <source>Y axis title font size</source>
      <translation>Velľkosť písma nadpisu na ose Y</translation>
    </message>
  </context>
  <context>
    <name>plot_positions</name>
    <message>
      <location filename="TaskPanel.py" line="121"/>
      <source>Set positions and sizes</source>
      <translation>Nastavenie pozície a veľkosti</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="126"/>
      <source>Position</source>
      <translation>Pozícia</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="132"/>
      <source>Size</source>
      <translation>Veľkosť</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="138"/>
      <source>List of modificable items</source>
      <translation>Zoznam upraviteľných položiek</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="144"/>
      <source>X item position</source>
      <translation>Poloha položky v smere X</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="150"/>
      <source>Y item position</source>
      <translation>Poloha položky v smere Y</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="156"/>
      <source>Item size</source>
      <translation>Veľkosť položky</translation>
    </message>
  </context>
  <context>
    <name>plot_save</name>
    <message>
      <location filename="TaskPanel.py" line="128"/>
      <source>Save figure</source>
      <translation>Uložiť znázornenie</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="133"/>
      <source>Inches</source>
      <translation>Palce</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="139"/>
      <source>Dots per Inch</source>
      <translation>Body na palec</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="145"/>
      <source>Output image file path</source>
      <translation>Umiestnenie súboru výstupného obrázku</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="151"/>
      <source>Show a file selection dialog</source>
      <translation>Zobraziť dialóg pre výber súboru</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="157"/>
      <source>X image size</source>
      <translation>Veľkosť obrázku v smere X</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="163"/>
      <source>Y image size</source>
      <translation>Veľkosť obrázku v smere Y</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="169"/>
      <source>Dots per point, with size will define output image resolution</source>
      <translation>Počet bodiek na bod, spolu s veľkosťou, definujú výstupné rozlíšenie obrázku</translation>
    </message>
  </context>
  <context>
    <name>plot_series</name>
    <message>
      <location filename="TaskPanel.py" line="154"/>
      <source>No label</source>
      <translation>Bez popisu</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="160"/>
      <source>Remove serie</source>
      <translation>Odobrať sériu</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="196"/>
      <source>Line style</source>
      <translation>Štýl čiary</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="172"/>
      <source>Marker</source>
      <translation>Značka</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="149"/>
      <source>Configure series</source>
      <translation>Nastavenie série</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="178"/>
      <source>List of available series</source>
      <translation>Zoznam dostupných sérií</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="184"/>
      <source>Line title</source>
      <translation>Nadpis na čiare</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="202"/>
      <source>Marker style</source>
      <translation>Štýl značky</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="208"/>
      <source>Line width</source>
      <translation>Hrúbka čiary</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="214"/>
      <source>Marker size</source>
      <translation>Veľkosť značky</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="220"/>
      <source>Line and marker color</source>
      <translation>Farba čiary a značky</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="226"/>
      <source>Removes this serie</source>
      <translation>Odobrať túto sériu</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="190"/>
      <source>If checked serie will not be considered for legend</source>
      <translation>Vybraná séria nebude zahrnutá v legende</translation>
    </message>
  </context>
</TS>

==> freecad_0.18.4+dfsg2.orig.tar.xz: FreeCAD-0.18.4/src/Mod/Plot/resources/translations/Plot_sk.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="sk" sourcelanguage="en">
  <context>
    <name>Plot</name>
    <message>
      <location filename="../../InitGui.py" line="44"/>
      <source>Plot edition tools</source>
      <translation>Nástroje úpravy grafu</translation>
    </message>
    <message>
      <location filename="../../InitGui.py" line="47"/>
      <source>Plot</source>
      <translation>Graf</translation>
    </message>
  </context>
  <context>
    <name>Plot_Axes</name>
    <message>
      <location filename="../../PlotGui.py" line="62"/>
      <source>Configure axes</source>
      <translation>Nastaviť osi</translation>
    </message>
    <message>
      <location filename="../../PlotGui.py" line="65"/>
      <source>Configure the axes parameters</source>
      <translation>Nastaviť parametre osí</translation>
    </message>
  </context>
  <context>
    <name>Plot_Grid</name>
    <message>
      <location filename="../../PlotGui.py" line="109"/>
      <source>Show/Hide grid</source>
      <translation>Zobraziť/skryť mriežku</translation>
    </message>
    <message>
      <location filename="../../PlotGui.py" line="112"/>
      <source>Show/Hide grid on selected plot</source>
      <translation>Zobraziť/skryť mriežku vybraného grafu</translation>
    </message>
  </context>
  <context>
    <name>Plot_Labels</name>
    <message>
      <location filename="../../PlotGui.py" line="152"/>
      <source>Set labels</source>
      <translation>Nastaviť popisy</translation>
    </message>
    <message>
      <location filename="../../PlotGui.py" line="155"/>
      <source>Set title and axes labels</source>
      <translation>Nastaviť nadpis a popisy osí</translation>
    </message>
  </context>
  <context>
    <name>Plot_Legend</name>
    <message>
      <location filename="../../PlotGui.py" line="135"/>
      <source>Show/Hide legend</source>
      <translation>Zobraziť/skryť legendu</translation>
    </message>
    <message>
      <location filename="../../PlotGui.py" line="138"/>
      <source>Show/Hide legend on selected plot</source>
      <translation>Zobraziť/skryť legendu vo vybranom grafe</translation>
    </message>
  </context>
  <context>
    <name>Plot_Positions</name>
    <message>
      <location filename="../../PlotGui.py" line="169"/>
      <source>Set positions and sizes</source>
      <translation>Nastavenie pozície a veľkosti</translation>
    </message>
    <message>
      <location filename="../../PlotGui.py" line="172"/>
      <source>Set labels and legend positions and sizes</source>
      <translation>Nastavenie pozície a veľkosti popisov a legendy</translation>
    </message>
  </context>
  <context>
    <name>Plot_SaveFig</name>
    <message>
      <location filename="../../PlotGui.py" line="45"/>
      <source>Save plot</source>
      <translation>Uložiť graf</translation>
    </message>
    <message>
      <location filename="../../PlotGui.py" line="48"/>
      <source>Save the plot as an image file</source>
      <translation>Uložiť graf ako obrázok</translation>
    </message>
  </context>
  <context>
    <name>Plot_Series</name>
    <message>
      <location filename="../../PlotGui.py" line="81"/>
      <source>Configure series</source>
      <translation>Nastavenie série</translation>
    </message>
    <message>
      <location filename="../../PlotGui.py" line="84"/>
      <source>Configure series drawing style and label</source>
      <translation>Nastavenie štýlu a popisu pre sériu</translation>
    </message>
  </context>
  <context>
    <name>plot_axes</name>
    <message>
      <location filename="../../plotAxes/TaskPanel.py" line="175"/>
      <source>Configure axes</source>
      <translation>Nastaviť osi</translation>
    </message>
    <message>
      <location filename="../../plotAxes/TaskPanel.py" line="179"/>
      <source>Active axes</source>
      <translation>Aktívne osi</translation>
    </message>
    <message>
      <location filename="../../plotAxes/TaskPanel.py" line="211"/>
      <source>Apply to all axes</source>
      <translation>Aplikovať na všetky osi</translation>
    </message>
    <message>
      <location filename="../../plotAxes/TaskPanel.py" line="215"/>
      <source>Dimensions</source>
      <translation>Rozmery</translation>
    </message>
    <message>
      <location filename="../../plotAxes/TaskPanel.py" line="219"/>
      <source>X axis position</source>
      <translation>Poloha osi X</translation>
    </message>
    <message>
      <location filename="../../plotAxes/TaskPanel.py" line="223"/>
      <source>Y axis position</source>
      <translation>Poloha osi Y</translation>
    </message>
    <message>
      <location filename="../../plotAxes/TaskPanel.py" line="199"/>
      <source>Scales</source>
      <translation>Mierka</translation>
    </message>
    <message>
      <location filename="../../plotAxes/TaskPanel.py" line="203"/>
      <source>X auto</source>
      <translation>X automaticky</translation>
    </message>
    <message>
      <location filename="../../plotAxes/TaskPanel.py" line="207"/>
      <source>Y auto</source>
      <translation>Y automaticky</translation>
    </message>
    <message>
      <location filename="../../plotAxes/TaskPanel.py" line="227"/>
      <source>Index of the active axes</source>
      <translation>Popis aktívnych osí</translation>
    </message>
    <message>
      <location filename="../../plotAxes/TaskPanel.py" line="231"/>
      <source>Add new axes to the plot</source>
      <translation>Pridať nové osi do grafu</translation>
    </message>
    <message>
      <location filename="../../plotAxes/TaskPanel.py" line="236"/>
      <source>Remove selected axes</source>
      <translation>Odobrať vybrané osi</translation>
    </message>
    <message>
      <location filename="../../plotAxes/TaskPanel.py" line="241"/>
      <source>Check it to apply transformations to all axes</source>
      <translation>Zaškrtnite pre povolenie transformácií vo všetkých osách</translation>
    </message>
    <message>
      <location filename="../../plotAxes/TaskPanel.py" line="246"/>
      <source>Left bound of axes</source>
      <translation>Ľavá medza osí</translation>
    </message>
    <message>
      <location filename="../../plotAxes/TaskPanel.py" line="251"/>
      <source>Right bound of axes</source>
      <translation>Pravá medza osí</translation>
    </message>
    <message>
      <location filename="../../plotAxes/TaskPanel.py" line="256"/>
      <source>Bottom bound of axes</source>
      <translation>Spodná medza osí</translation>
    </message>
    <message>
      <location filename="../../plotAxes/TaskPanel.py" line="261"/>
      <source>Top bound of axes</source>
      <translation>Horná medza osí</translation>
    </message>
    <message>
      <location filename="../../plotAxes/TaskPanel.py" line="266"/>
      <source>Outward offset of X axis</source>
      <translation>Vonkajšie odsadenie osi X</translation>
    </message>
    <message>
      <location filename="../../plotAxes/TaskPanel.py" line="271"/>
      <source>Outward offset of Y axis</source>
      <translation>Vonkajšie odsadenie osi Y</translation>
    </message>
    <message>
      <location filename="../../plotAxes/TaskPanel.py" line="276"/>
      <source>X axis scale autoselection</source>
      <translation>Automatická mierka osi X</translation>
    </message>
    <message>
      <location filename="../../plotAxes/TaskPanel.py" line="281"/>
      <source>Y axis scale autoselection</source>
      <translation>Automatická mierka osi Y</translation>
    </message>
  </context>
  <context>
    <name>plot_console</name>
    <message>
      <location filename="../../Plot.py" line="43"/>
      <source>matplotlib not found, so Plot module can not be loaded</source>
      <translation>modul Graf nemohol byť načítaný, pretože knižnica matplotlib nebola nájdená</translation>
    </message>
    <message>
      <location filename="../../InitGui.py" line="54"/>
      <source>matplotlib not found, Plot module will be disabled</source>
      <translation>knižnica matplotlib nebola nájdená, modul Graf bude deaktivovaný</translation>
    </message>
    <message>
      <location filename="../../plotSave/TaskPanel.py" line="42"/>
      <source>Plot document must be selected in order to save it</source>
      <translation>Dokument grafu musí byť vybraný, aby mohol byť uložený</translation>
    </message>
    <message>
      <location filename="../../plotAxes/TaskPanel.py" line="340"/>
      <source>Axes 0 can not be deleted</source>
      <translation>Osi 0 nemôžu byť zmazané</translation>
    </message>
    <message>
      <location filename="../../PlotGui.py" line="97"/>
      <source>The grid must be activated on top of a plot document</source>
      <translation>Mriežka grafu musí byť aktivovaná hore v dokumente grafu</translation>
    </message>
    <message>
      <location filename="../../PlotGui.py" line="125"/>
      <source>The legend must be activated on top of a plot document</source>
      <translation>Legenda musí byť aktivovaná hore v dokumente grafu</translation>
    </message>
  </context>
  <context>
    <name>plot_labels</name>
    <message>
      <location filename="../../plotLabels/TaskPanel.py" line="133"/>
      <source>Set labels</source>
      <translation>Nastaviť popisy</translation>
    </message>
    <message>
      <location filename="../../plotLabels/TaskPanel.py" line="137"/>
      <source>Active axes</source>
      <translation>Aktívne osi</translation>
    </message>
    <message>
      <location filename="../../plotLabels/TaskPanel.py" line="141"/>
      <source>Title</source>
      <translation>Nadpis</translation>
    </message>
    <message>
      <location filename="../../plotLabels/TaskPanel.py" line="145"/>
      <source>X label</source>
      <translation>Popis osi X</translation>
    </message>
    <message>
      <location filename="../../plotLabels/TaskPanel.py" line="149"/>
      <source>Y label</source>
      <translation>Popis osi Y</translation>
    </message>
    <message>
      <location filename="../../plotLabels/TaskPanel.py" line="153"/>
      <source>Index of the active axes</source>
      <translation>Popis aktívnych osí</translation>
    </message>
    <message>
      <location filename="../../plotLabels/TaskPanel.py" line="157"/>
      <source>Title (associated to active axes)</source>
      <translation>Nadpis (pripojený k aktívnym osám)</translation>
    </message>
    <message>
      <location filename="../../plotLabels/TaskPanel.py" line="162"/>
      <source>Title font size</source>
      <translation>Veľkosť písma nadpisu</translation>
    </message>
    <message>
      <location filename="../../plotLabels/TaskPanel.py" line="167"/>
      <source>X axis title</source>
      <translation>Nadpis na ose X</translation>
    </message>
    <message>
      <location filename="../../plotLabels/TaskPanel.py" line="172"/>
      <source>X axis title font size</source>
      <translation>Velľkosť písma nadpisu na ose X</translation>
    </message>
    <message>
      <location filename="../../plotLabels/TaskPanel.py" line="177"/>
      <source>Y axis title</source>
      <translation>Nadpis na ose Y</translation>
    </message>
    <message>
      <location filename="../../plotLabels/TaskPanel.py" line="182"/>
      <source>Y axis title font size</source>
      <translation>Velľkosť písma nadpisu na ose Y</translation>
    </message>
  </context>
  <context>
    <name>plot_positions</name>
    <message>
      <location filename="../../plotPositions/TaskPanel.py" line="121"/>
      <source>Set positions and sizes</source>
      <translation>Nastavenie pozície a veľkosti</translation>
    </message>
    <message>
      <location filename="../../plotPositions/TaskPanel.py" line="125"/>
      <source>Position</source>
      <translation>Pozícia</translation>
    </message>
    <message>
      <location filename="../../plotPositions/TaskPanel.py" line="130"/>
      <source>Size</source>
      <translation>Veľkosť</translation>
    </message>
    <message>
      <location filename="../../plotPositions/TaskPanel.py" line="140"/>
      <source>X item position</source>
      <translation>Poloha položky v smere X</translation>
    </message>
    <message>
      <location filename="../../plotPositions/TaskPanel.py" line="145"/>
      <source>Y item position</source>
      <translation>Poloha položky v smere Y</translation>
    </message>
    <message>
      <location filename="../../plotPositions/TaskPanel.py" line="150"/>
      <source>Item size</source>
      <translation>Veľkosť položky</translation>
    </message>
    <message>
      <location filename="../../plotPositions/TaskPanel.py" line="135"/>
      <source>List of modifiable items</source>
      <translation type="unfinished">List of modifiable items</translation>
    </message>
  </context>
  <context>
    <name>plot_save</name>
    <message>
      <location filename="../../plotSave/TaskPanel.py" line="127"/>
      <source>Save figure</source>
      <translation>Uložiť znázornenie</translation>
    </message>
    <message>
      <location filename="../../plotSave/TaskPanel.py" line="131"/>
      <source>Inches</source>
      <translation>Palce</translation>
    </message>
    <message>
      <location filename="../../plotSave/TaskPanel.py" line="136"/>
      <source>Dots per Inch</source>
      <translation>Body na palec</translation>
    </message>
    <message>
      <location filename="../../plotSave/TaskPanel.py" line="141"/>
      <source>Output image file path</source>
      <translation>Umiestnenie súboru výstupného obrázku</translation>
    </message>
    <message>
      <location filename="../../plotSave/TaskPanel.py" line="146"/>
      <source>Show a file selection dialog</source>
      <translation>Zobraziť dialóg pre výber súboru</translation>
    </message>
    <message>
      <location filename="../../plotSave/TaskPanel.py" line="151"/>
      <source>X image size</source>
      <translation>Veľkosť obrázku v smere X</translation>
    </message>
    <message>
      <location filename="../../plotSave/TaskPanel.py" line="156"/>
      <source>Y image size</source>
      <translation>Veľkosť obrázku v smere Y</translation>
    </message>
    <message>
      <location filename="../../plotSave/TaskPanel.py" line="161"/>
      <source>Dots per point, with size will define output image resolution</source>
      <translation>Počet bodiek na bod, spolu s veľkosťou, definujú výstupné rozlíšenie obrázku</translation>
    </message>
  </context>
  <context>
    <name>plot_series</name>
    <message>
      <location filename="../../plotSeries/TaskPanel.py" line="153"/>
      <source>No label</source>
      <translation>Bez popisu</translation>
    </message>
    <message>
      <location filename="../../plotSeries/TaskPanel.py" line="188"/>
      <source>Line style</source>
      <translation>Štýl čiary</translation>
    </message>
    <message>
      <location filename="../../plotSeries/TaskPanel.py" line="168"/>
      <source>Marker</source>
      <translation>Značka</translation>
    </message>
    <message>
      <location filename="../../plotSeries/TaskPanel.py" line="149"/>
      <source>Configure series</source>
      <translation>Nastavenie série</translation>
    </message>
    <message>
      <location filename="../../plotSeries/TaskPanel.py" line="173"/>
      <source>List of available series</source>
      <translation>Zoznam dostupných sérií</translation>
    </message>
    <message>
      <location filename="../../plotSeries/TaskPanel.py" line="178"/>
      <source>Line title</source>
      <translation>Nadpis na čiare</translation>
    </message>
    <message>
      <location filename="../../plotSeries/TaskPanel.py" line="193"/>
      <source>Marker style</source>
      <translation>Štýl značky</translation>
    </message>
    <message>
      <location filename="../../plotSeries/TaskPanel.py" line="198"/>
      <source>Line width</source>
      <translation>Hrúbka čiary</translation>
    </message>
    <message>
      <location filename="../../plotSeries/TaskPanel.py" line="203"/>
      <source>Marker size</source>
      <translation>Veľkosť značky</translation>
    </message>
    <message>
      <location filename="../../plotSeries/TaskPanel.py" line="208"/>
      <source>Line and marker color</source>
      <translation>Farba čiary a značky</translation>
    </message>
    <message>
      <location filename="../../plotSeries/TaskPanel.py" line="158"/>
      <source>Remove series</source>
      <translation type="unfinished">Remove series</translation>
    </message>
    <message>
      <location filename="../../plotSeries/TaskPanel.py" line="183"/>
      <source>If checked, series will not be considered for legend</source>
      <translation type="unfinished">If checked, series will not be considered for legend</translation>
    </message>
    <message>
      <location filename="../../plotSeries/TaskPanel.py" line="213"/>
      <source>Removes this series</source>
      <translation type="unfinished">Removes this series</translation>
    </message>
  </context>
</TS>
